@@ -16,7 +16,7 @@ use Perinci::Sub::Util qw(err);
 use Term::Detect::Software qw(detect_terminal_cached);
 use Time::HiRes qw(time);
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 our $DATE = '2014-07-02'; # DATE
 
 my $cleanser = Data::Clean::JSON->get_cleanser;
@@ -617,12 +617,12 @@ sub catch_comp {
 
     local $ENV{COMP_LINE} = $line;
     local $ENV{COMP_POINT} = $start + length($word);
-    $res = Perinci::Sub::Complete::shell_complete_arg(
+    $res = Perinci::Sub::Complete::complete_cli_arg(
         meta => $meta,
         riap_server_url => $self->state('server_url'),
         riap_uri        => $uri,
         riap_client     => $self->{_pa},
-        common_opts => [qw/--help -h -? --verbose -v --json/],
+        common_opts     => [qw/--help -h -? --verbose -v --json/],
         extra_completer_args => {-shell => $self},
     );
 
@@ -672,7 +672,7 @@ sub _install_cmds {
             local $self->{_in_completion} = 1;
             local $ENV{COMP_LINE} = $line;
             local $ENV{COMP_POINT} = $start + length($word);
-            my $res = Perinci::Sub::Complete::shell_complete_arg(
+            my $res = Perinci::Sub::Complete::complete_cli_arg(
                 meta => $meta,
                 common_opts => [qw/--help -h -? --verbose -v --json/],
                 extra_completer_args => {-shell => $self},
@@ -710,7 +710,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
